@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2025 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,6 +8,13 @@
 #
 # Thanks for using Enthought open source!
 
+from traits.observation.events import (
+    DictChangeEvent,
+    ListChangeEvent,
+    SetChangeEvent,
+    TraitChangeEvent,
+)
+
 from traits.observation.exception_handling import (
     pop_exception_handler,
     push_exception_handler,
