@@ -1,3 +1,13 @@
+# (C) Copyright 2005-2025 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Tools for having doctest and unittest work together more nicely.
 
     Eclipse's PyDev plugin will run your unittest files for you very nicely.
@@ -7,7 +17,6 @@
 
 # Standard library imports
 import doctest
-import sys
 import unittest
 
 
