@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2025 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -16,20 +16,44 @@ traits, and provides a richer API than the old-style traits derived from
 ``TraitHandler``.
 """
 
-import warnings
+import logging
 
 from .base_trait_handler import BaseTraitHandler
-from .constants import ComparisonMode, DefaultValue, TraitKind
+from .constants import DefaultValue, TraitKind
 from .trait_base import Missing, Self, TraitsCache, Undefined, class_of
 from .trait_dict_object import TraitDictObject
 from .trait_errors import TraitError
 from .trait_list_object import TraitListObject
 from .trait_set_object import TraitSetObject
 
+#: Logger instance for this module
+logger = logging.getLogger(__name__)
 
 #: Mapping from trait metadata 'type' to CTrait 'type':
 trait_types = {"python": 1, "event": 2}
 
+#: DefaultValue kinds that have to copy a new default value when cloned
+clone_copies_default_value = {
+    DefaultValue.trait_list_object,
+    DefaultValue.trait_dict_object,
+    DefaultValue.trait_set_object,
+}
+
+#: DefaultValue types that become constant type when given a new default
+clone_becomes_constant_default_value = {
+    DefaultValue.callable_and_args,
+    DefaultValue.callable,
+    DefaultValue.object,
+    # the following are being phased out
+    DefaultValue.list_copy,
+    DefaultValue.dict_copy,
+}
+
+#: DefaultValue types that cannot take a default value when cloned
+clone_no_override_default_value = {
+    DefaultValue.disallow,
+}
+
 
 def _infer_default_value_type(default_value):
     """ Figure out the default value type given a default value.
@@ -152,7 +176,7 @@ class TraitType(BaseTraitHandler):
         the ``value`` being assigned. It should return ``True`` if the value is
         valid, and ``False`` otherwise.
 
-    ``value_for ( self, value )``
+    ``value_for(self, value)``
 
         As another alternative to implementing the ``validate`` method, you
         can instead implement the ``value_for`` method, which receives only
@@ -281,6 +305,11 @@ class TraitType(BaseTraitHandler):
             A dictionary of metadata names and corresponding values as
             arbitrary keyword arguments.
 
+        Returns
+        -------
+        clone : TraitType
+            Clone of self.
+
         """
         if "parent" not in metadata:
             metadata["parent"] = self
@@ -300,14 +329,46 @@ class TraitType(BaseTraitHandler):
         new._metadata.update(metadata)
 
         if default_value is not NoDefaultSpecified:
-            new.default_value = default_value
-            if self.validate is not None:
+            if new.default_value_type in clone_no_override_default_value:
+                raise TraitError(
+                    f"Can't override default value of cloned {new} trait",
+                )
+
+            # does the trait want the original value as the default?
+            # TODO: since this is needed here, it should also be a property of
+            # the TraitType, not just the CTrait.
+            # xref: enthought/traits#1695
+            setattr_original_value = new.as_ctrait().setattr_original_value
+
+            # try to validate the new default value
+            if not (self.validate is None or setattr_original_value):
                 try:
-                    new.default_value = self.validate(
-                        None, None, default_value
+                    default_value = self.validate(None, None, default_value)
+                except Exception as exc:
+                    # this is expected for traits which need object or name
+                    # information to properly validate (eg. This() trait)
+                    # TODO: override This.clone() and similar for better
+                    # behaviour and raise an exception here.
+                    # xref: enthought/traits#1696
+                    logger.debug(
+                        f"Validation failed cloning {self} with "
+                        f"default value {default_value}: {exc}",
+                        exc_info=True,
                     )
-                except Exception:
-                    pass
+
+            if new.default_value_type in clone_copies_default_value:
+                default_value = default_value.copy()
+
+            if new.default_value_type in clone_becomes_constant_default_value:
+                # Note that a mutable default value will be shared across
+                # instances; this may not always be the desired behaviour,
+                # especially for trait types using a callable_and_args default.
+                # TraitType subclasses that need a different behaviour should
+                # override or extend the clone() method.
+                # xref: enthought/traits#1630
+                new.default_value_type = DefaultValue.constant
+
+            new.default_value = default_value
 
         return new
 
@@ -406,23 +467,6 @@ class TraitType(BaseTraitHandler):
                 trait.post_setattr = post_setattr
                 trait.is_mapped = self.is_mapped
 
-            # Note: The use of 'rich_compare' metadata is deprecated; use
-            # 'comparison_mode' metadata instead. Ref: enthought/traits#602.
-            rich_compare = metadata.get("rich_compare")
-            if rich_compare is not None:
-                warnings.warn(
-                    "The 'rich_compare' metadata has been deprecated. Please "
-                    "use the 'comparison_mode' metadata instead. In a future "
-                    "release, rich_compare will have no effect.",
-                    DeprecationWarning,
-                    stacklevel=6,
-                )
-
-                if rich_compare:
-                    trait.comparison_mode = ComparisonMode.equality
-                else:
-                    trait.comparison_mode = ComparisonMode.identity
-
             comparison_mode = metadata.pop("comparison_mode", None)
             if comparison_mode is not None:
                 trait.comparison_mode = comparison_mode
